==> gatsby-theme-docs-2.0.4.tgz: package/README.md <==
<p align="center">
  <img src="https://rocketseat-cdn.s3-sa-east-1.amazonaws.com/theme-docs.svg" alt="A illustration of file that is the @rocketseat/gatsby-theme-docs logo" width="100">
</p>

<h2 align="center">
  @rocketseat/gatsby-theme-docs
</h2>

<p align="center">
  Out of the box Gatsby Theme for creating documentation websites easily and quickly.
</p>

<p align="center">
  <img src="https://img.shields.io/badge/PRs-welcome-%237159c1.svg" alt="PRs welcome!" />

  <img alt="License" src="https://img.shields.io/badge/license-MIT-%237159c1">

  <a href="https://twitter.com/intent/follow?screen_name=rocketseat">
    <img src="https://img.shields.io/twitter/follow/rocketseat.svg?label=Follow%20@rocketseat" alt="Follow @rocketseat" />
  </a>
</p>

<p align="center">
  <a href="#-features">Features</a> •
  <a href="#%EF%B8%8F-getting-started">Getting started</a> •
  <a href="#-docs">Docs</a> •
  <a href="#-contributing">Contributing</a> •
  <a href="#memo-license">License</a>
</p>

## 🚀 Features

- 📝 MDX for docs;
- 🛣 Yaml-based sidebar navigation;
- 📱 Responsive and mobile friendly;
- 🖥 Code highlighting with [prism-react-renderer](https://github.com/FormidableLabs/prism-react-renderer) and [react-live](https://github.com/FormidableLabs/react-live) support;
- 🥇 SEO (Sitemap, schema.org data, Open Graph and Twitter tags).
- 📈 Google Analytics support;
- 📄 Custom docs schema;
- ⚡️ Offline Support & WebApp Manifest;
- and much more 🔥

## ⚡️ Getting started

1. Create the website.

```sh
gatsby new rocket-docs https://github.com/rocketseat/gatsby-starter-rocket-docs
```

2. Start developing.

```sh
cd rocket-docs
gatsby develop
```

3. Are you ready for launch? 🚀

Your site is now running at `http://localhost:8000`

## 📄 Docs

Looking for docs? Check our live demo and documentation [website](https://rocketdocs.netlify.com).

## ✨ Contributing

Thanks for being interested in contributing! We’re so glad you want to help! Please take a little bit of your time and look at our [contributing guidelines](https://github.com/Rocketseat/gatsby-themes/blob/master/.github/CONTRIBUTING.md) and our
[code of conduct](https://github.com/Rocketseat/gatsby-themes/blob/master/.github/CODE_OF_CONDUCT.md)! All type of contributions are welcome, such as bug fixes, issues or feature requests. Also, don't forget to check the [roadmap](#roadmap).

## 🗺 Roadmap

If you'd like to see our next steps or in which feature our bug fix we are working on, please check our [roadmap project](https://github.com/Rocketseat/gatsby-themes/projects/2).

## 📝 License

Licensed under the [MIT License](./LICENSE).

---

Made with 💜 by Rocketseat :wave: [check our community!](https://discordapp.com/invite/gCRAFhc)

==> gatsby-theme-docs-2.1.1.tgz: package/README.md <==
<p align="center">
  <img src="https://rocketseat-cdn.s3-sa-east-1.amazonaws.com/theme-docs.svg" alt="A illustration of file that is the @rocketseat/gatsby-theme-docs logo" width="100">
</p>

<h2 align="center">
  @rocketseat/gatsby-theme-docs
</h2>

<p align="center">
  Out of the box Gatsby Theme for creating documentation websites easily and quickly.
</p>

<p align="center">
  <img src="https://img.shields.io/badge/PRs-welcome-%237159c1.svg" alt="PRs welcome!" />

  <img alt="License" src="https://img.shields.io/badge/license-MIT-%237159c1">

  <a href="https://twitter.com/intent/follow?screen_name=rocketseat">
    <img src="https://img.shields.io/twitter/follow/rocketseat.svg?label=Follow%20@rocketseat" alt="Follow @rocketseat" />
  </a>
</p>

<p align="center">
  <a href="#-features">Features</a> •
  <a href="#%EF%B8%8F-getting-started">Getting started</a> •
  <a href="#-docs">Docs</a> •
  <a href="#-contributing">Contributing</a> •
  <a href="#memo-license">License</a>
</p>

## 🚀 Features

- 📝 MDX for docs;
- 🛣 Yaml-based sidebar navigation;
- 📱 Responsive and mobile friendly;
- 🖥 Code highlighting with [prism-react-renderer](https://github.com/FormidableLabs/prism-react-renderer) and [react-live](https://github.com/FormidableLabs/react-live) support;
- 🥇 SEO (Sitemap, schema.org data, Open Graph and Twitter tags).
- 📈 Google Analytics support;
- 📄 Custom docs schema;
- ⚡️ Offline Support & WebApp Manifest;
- and much more 🔥

## ⚡️ Getting started

1. Create the website.

   ```sh
   gatsby new rocket-docs https://github.com/rocketseat/gatsby-starter-rocket-docs
   ```

2. Start developing.

   ```sh
   cd rocket-docs
   gatsby develop
   ```

3. Are you ready for launch? 🚀

   Your site is now running at `http://localhost:8000`

## 📄 Docs

Looking for docs? Check our live demo and documentation [website](https://rocketdocs.netlify.com).

## ✨ Contributing

Thanks for being interested in contributing! We’re so glad you want to help! Please take a little bit of your time and look at our [contributing guidelines](https://github.com/Rocketseat/gatsby-themes/blob/master/.github/CONTRIBUTING.md) and our
[code of conduct](https://github.com/Rocketseat/gatsby-themes/blob/master/.github/CODE_OF_CONDUCT.md)! All type of contributions are welcome, such as bug fixes, issues or feature requests. Also, don't forget to check the [roadmap](#roadmap).

## 🗺 Roadmap

If you'd like to see our next steps or in which feature our bug fix we are working on, please check our [project roadmap](https://github.com/Rocketseat/gatsby-themes/projects/2).

## 📝 License

Licensed under the [MIT License](./LICENSE).

---

Made with 💜 by Rocketseat :wave: [check our community!](https://discordapp.com/invite/gCRAFhc)
